Actions

Struct Actions 

pub struct Actions { /* private fields */ }
Possible actions to be taken on a connection

Implementations

Source

impl Actions

pub const Update: Actions

Invoke Tracked datatype “Update” API at this Layer to pass new frames to users’ subscribed datatype(s).

pub const Parse: Actions

Indicates that some Layer-specific stateful parsing is required. For L4, this means that some subscription requires reassembled updates (separate from protocol parsing, which is handled by PassThrough). For L6/L7, this indicates a stateful application-layer protocol parser should be invoked.

pub const PassThrough: Actions

Indicates that some child layer(s) require actions. For TCP connections, this will trigger reassembly.

pub const Track: Actions

Track the connection, updating with state transitions.

pub const fn bits(&self) -> u8

Returns the underlying bits of the bitmask.

pub const fn all_bits() -> Self

Returns a bitmask that contains all values.

This will include bits that do not have any flags. Use ::all_flags() if you only want to use flags.

pub const fn all_flags() -> Self

Returns a bitmask that contains all flags.

pub const fn is_all_bits(&self) -> bool

Returns true if the bitmask contains all values.

This will check for bits == !0, use .is_all_flags() if you only want to check for all flags

pub const fn is_all_flags(&self) -> bool

Returns true if the bitmask contains all flags.

This will fail if any unused bit is set, consider using .truncate() first.

pub const fn all() -> Self

👎Deprecated: Please use the ::all_bits() constructor

Returns a bitmask that contains all values.

This will include bits that do not have any flags. Use ::all_flags() if you only want to use flags.

pub const fn is_all(&self) -> bool

👎Deprecated: Please use the .is_all_bits() method

Returns true if the bitmask contains all values.

This will check for bits == !0, use .is_all_flags() if you only want to check for all flags

pub const fn full() -> Self

👎Deprecated: Please use the ::all_flags() constructor

Returns a bitmask that contains all flags.

pub const fn is_full(&self) -> bool

👎Deprecated: Please use the .is_all_flags() method

Returns true if the bitmask contains all flags.

This will fail if any unused bit is set, consider using .truncate() first.

pub const fn none() -> Self

Returns a bitmask that does not contain any values.

pub const fn is_none(&self) -> bool

Returns true if the bitmask does not contain any values.

pub const fn truncate(&self) -> Self

Returns a bitmask that only has bits corresponding to flags

pub const fn intersects(&self, other: Self) -> bool

Returns true if self intersects with any value in other, or if other does not contain any values.

This is equivalent to (self & other) != 0 || other == 0.

pub const fn contains(&self, other: Self) -> bool

Returns true if self contains all values of other.

This is equivalent to (self & other) == other.

pub const fn not(self) -> Self

Returns the bitwise NOT of the bitmask.

pub const fn and(self, other: Self) -> Self

Returns the bitwise AND of the bitmask.

pub const fn or(self, other: Self) -> Self

Returns the bitwise OR of the bitmask.

pub const fn xor(self, other: Self) -> Self

Returns the bitwise XOR of the bitmask.